python-ndn
==========

|Test Badge|
|Code Size|
|Release Badge|
|Doc Badge|

A Named Data Networking client library with AsyncIO support in Python 3.

It supports Python >=3.6 and PyPy3 >=7.1.1.

Please see our documentation_ if you have any issues.

.. |Test Badge| image:: https://github.com/named-data/python-ndn/workflows/test/badge.svg
    :target: https://github.com/named-data/python-ndn
    :alt: Test Status

.. |Code Size| image:: https://img.shields.io/github/languages/code-size/named-data/python-ndn
    :target: https://github.com/named-data/python-ndn
    :alt: Code Size

.. |Release Badge| image:: https://img.shields.io/pypi/v/python-ndn?label=release
    :target: https://pypi.org/project/python-ndn/
    :alt: Release Ver

.. |Doc Badge| image:: https://readthedocs.org/projects/python-ndn/badge/?version=latest
    :target: https://python-ndn.readthedocs.io/en/latest/?badge=latest
    :alt: Doc Status

.. _documentation: https://python-ndn.readthedocs.io/en/latest
